@@ -1,6 +1,8 @@
 describe.lognorm<-function(){
-category <- "censored"
+category <- "bounded"
 description  <- "Log-Normal Regression for Duration Dependent Variables"
+authors <- c()
+year <- 2007
 package <-list(	name 	="survival",
 		version	="2.2"
 		)
@@ -13,5 +15,5 @@ parameters$mu<-list(equations=c(1,1),
 			varInSpecialFunction=c(2,2)
 		)
 			
-list(category=category,description=description,package=package,parameters=parameters)
+list(category = category, authors = authors, year = year,description=description,package=package,parameters=parameters)
 }
