@@ -1,8 +1,10 @@
-describe.netls<-function(){
+describe.ls.net<-function(){
 category <- "continuous"
 description  <- "Social Network Least Squares Regression for Continuous Dependent Variables"
+authors <- c("Skyler J. Cranmer")
+year <- 2007
 package <-list(	name 	="sna",
-		version	="0.1"
+		version	="1.4"
 		)
 parameters<-list(mu="mu")
 parameters$mu<-list(equations=c(1,1),
@@ -11,5 +13,5 @@ parameters$mu<-list(equations=c(1,1),
 			expVar=TRUE
 			)
 			
-list(category=category,description=description,package=package,parameters=parameters)
+list(category = category, authors = authors, year = year,description=description,package=package,parameters=parameters)
 }
