@@ -3,8 +3,8 @@ zelig2relogit <- function(formula, model, data, M, ...) {
   mf$model <- mf$M <- mf$robust <- NULL
   if (is.null(mf$case.control))
     mf$case.control <- "prior"
-  mf$formula <- as.formula(paste("cbind(", formula[[2]], ", 1 -", formula[[2]], ")",
-                                 "~", deparse(formula[[3]]), sep = ""))
+  ## transforms y ~ rhs into cbind(y, 1-y) ~ rhs
+  mf$formula<- as.formula(call("~", call("cbind",formula[[2]], call("-",1, formula[[2]])), formula[[3]]))
   if (is.null(mf$bias.correct))
     mf$bias.correct <- TRUE
   mf[[1]] <- as.name("relogit")
